CREATE SEQUENCE messages_id_seq;
CREATE TABLE messages 
 (
    id BIGINT NOT NULL DEFAULT nextval('messages_id_seq'), 
    ip VARCHAR(110) NOT NULL DEFAULT '0',
    rtime INTEGER NOT NULL,
    facility INTEGER NOT NULL, 
    severity INTEGER NOT NULL, 
    mtime INTEGER NOT NULL,
    host VARCHAR(129) DEFAULT NULL, 
    ident VARCHAR(80) DEFAULT NULL, 
    pid VARCHAR(128), 
    event BIGINT,
    msg TEXT NOT NULL, 
    fts TEXT DEFAULT '',
    PRIMARY KEY (id, rtime)
 );
CREATE INDEX messages_fts_idx ON messages USING gin( to_tsvector('english', fts) );
CREATE TRIGGER insert_messages_trigger
	BEFORE INSERT ON messages
	FOR EACH ROW EXECUTE PROCEDURE messages_insert_trigger();

CREATE SEQUENCE settings_id_seq;
CREATE TABLE settings
 (
    id INT NOT NULL DEFAULT nextval('settings_id_seq'),
    local_storage_path VARCHAR,
    remote_storage_path VARCHAR,
    keep_in_db INTEGER,
    keep_in_local INTEGER,
    keep_in_remote INTEGER,
    create_fts_index BOOLEAN,
    monitor_host VARCHAR,
    use_ninja BOOLEAN,
        host_info_url VARCHAR,
        use_ldap BOOLEAN NOT NULL DEFAULT FALSE,
        compressed_filesize_modifier INT NOT NULL DEFAULT 100,
        min_disk_size_free INT NOT NULL DEFAULT 500,
    PRIMARY KEY(id)
 );
INSERT INTO settings(local_storage_path, remote_storage_path, keep_in_db, keep_in_local, keep_in_remote, create_fts_index, monitor_host, use_ninja, host_info_url) VALUES('/opt/logserver/archive', NULL, 5, 5, 5, TRUE, '', FALSE, '');

CREATE TABLE query_queue
(
	id SERIAL UNIQUE,
	lsfilter VARCHAR NOT NULL,
	query VARCHAR NOT NULL,
	interval_begin TIMESTAMP WITHOUT TIME ZONE NOT NULL DEFAULT '1970-01-01 01:00:00',
	interval_end TIMESTAMP WITHOUT TIME ZONE NOT NULL DEFAULT localtimestamp,
	started TIMESTAMP WITHOUT TIME ZONE DEFAULT NULL,
	finished TIMESTAMP WITHOUT TIME ZONE DEFAULT NULL,
	PRIMARY KEY(id)
);
